""" override default setting by adding `PERMISSIONS_SETTINGS` to your settings.py
then run manage.py migrate or manage.py sync_permissions to sync your PERMISSIONS
"""

__version__ = "0.0.1"


from plain_permissions.settings import permissions_settings
