from os import path

from setuptools import setup


this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md"), encoding="utf-8") as f:
    long_description = f.read()
if __name__ == "__main__":
    setup(long_description=long_description, long_description_content_type="text/markdown")
